Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(630)

Unified Diff: net/socket_stream/socket_stream.h

Issue 346010: Refactor SocketStream to report error to the delegate. (Closed)
Patch Set: update Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/socket_stream/socket_stream.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/socket_stream/socket_stream.h
diff --git a/net/socket_stream/socket_stream.h b/net/socket_stream/socket_stream.h
index c1aaf6eed50aa2d45c0890bd8a930ee132bb6d8e..b9961f49bc857bec0798be3fbfc6f265bc15f345 100644
--- a/net/socket_stream/socket_stream.h
+++ b/net/socket_stream/socket_stream.h
@@ -79,6 +79,11 @@ class SocketStream : public base::RefCountedThreadSafe<SocketStream> {
// By default, no credential is available and close the connection.
socket->Close();
}
+
+ // Called when an error occured.
+ // This is only for error reporting to the delegate.
+ // |error| is net::Error.
+ virtual void OnError(const SocketStream* socket, int error) {}
};
SocketStream(const GURL& url, Delegate* delegate);
@@ -171,7 +176,8 @@ class SocketStream : public base::RefCountedThreadSafe<SocketStream> {
STATE_SOCKS_CONNECT_COMPLETE,
STATE_SSL_CONNECT,
STATE_SSL_CONNECT_COMPLETE,
- STATE_READ_WRITE
+ STATE_READ_WRITE,
+ STATE_AUTH_REQUIRED,
};
enum ProxyMode {
@@ -184,11 +190,12 @@ class SocketStream : public base::RefCountedThreadSafe<SocketStream> {
friend class base::RefCountedThreadSafe<SocketStream>;
~SocketStream();
// Finish the job. Once finished, calls OnClose of delegate, and no more
// notifications will be sent to delegate.
- void Finish();
+ void Finish(int result);
- void DidEstablishConnection();
+ int DidEstablishConnection();
void DidReceiveData(int result);
void DidSendData(int result);
@@ -196,7 +203,7 @@ class SocketStream : public base::RefCountedThreadSafe<SocketStream> {
void OnReadCompleted(int result);
void OnWriteCompleted(int result);
- int DoLoop(int result);
+ void DoLoop(int result);
int DoResolveProxy();
int DoResolveProxyComplete(int result);
« no previous file with comments | « no previous file | net/socket_stream/socket_stream.cc » ('j') | no next file with comments »
@@ -184,11 +190,12 @@ class SocketStream : public base::RefCountedThreadSafe<SocketStream> {
friend class base::RefCountedThreadSafe<SocketStream>;
~SocketStream();
- // Finish the job. Once finished, calls OnClose of delegate, and no more
+ // Finishes the job.
+ // Calls OnError and OnClose of delegate, and no more
// notifications will be sent to delegate.

Powered by Google App Engine
This is Rietveld 408576698